# -*- coding: utf-8 flake8: noqa -*-
from .test_views import *
